@@ -2,17 +2,19 @@ package Regexp::Ethiopic::Amharic;
 use base qw(Regexp::Ethiopic);  #  this might be more useful later,
                                 #  we at least get "Exporter" for free.
 
-use utf8;
 BEGIN
 {
 use strict;
-use vars qw($VERSION @EXPORT_OK %AmharicEquivalence %AmharicClassEquivalence);
+use utf8;
+use vars qw($VERSION @EXPORT_OK %AmharicEquivalence %AmharicClassEquivalence $reIndex);
+# require Regexp::Ethiopic;
 
 
-	$VERSION = "0.05";
+	$VERSION = 0.01;
 	
 	@EXPORT_OK = qw(%AmharicEquivalence %AmharicClassEquivalence);
 
+	$reIndex = 0;
 
 #
 #  Amharic Rules Orthography Equivalence
@@ -117,7 +119,6 @@ foreach (ord('ጸ')..ord('ጾ')) {
 #
 %AmharicClassEquivalence =(
 	ሀ	=> "ሀ-ሆሐ-ሗኀ-ኆኈ-ኍኸ-ኾዀ-ዅ",
-	ሰ	=> "ሰ-ሷሠ-ሧ",
 	አ	=> "አ-ኧዐ-ዖ",
 	ጸ	=> "ጸ-ጿፀ-ፆ"
 );
@@ -126,9 +127,6 @@ $AmharicClassEquivalence{'ሐ'}
 	= $AmharicClassEquivalence{'ኸ'}
 	= $AmharicClassEquivalence{'ሀ'}
 	;
-$AmharicClassEquivalence{'ሠ'}
-	= $AmharicClassEquivalence{'ሰ'}
-	;
 $AmharicClassEquivalence{'ዐ'}
 	= $AmharicClassEquivalence{'አ'}
 	;
@@ -137,17 +135,17 @@ $AmharicClassEquivalence{'ፀ'}
 	;
 }
 
-
 sub import
 {
 
 	my @args = ( shift ); # package
 	foreach (@_) {
-		if ( /overload/o ) {
+		if ( /overload/ ) {
 			use overload;
 			overload::constant 'qr' => \&getRe;
+			$reIndex = 1;  # the valid utf-8 arg in the call back
 		}
-		elsif ( /EthiopicClasses|(sub|[gs]et)Form|:forms|:utils/ ) {
+		elsif ( /EthiopicClasses/ ) {
 			Regexp::Ethiopic->export_to_level (1, "Regexp::Ethiopic", $_);
 		}
 		else {
@@ -161,38 +159,13 @@ sub import
 }
 
 
-#
-# move into Regexp::Ethiopic later...
-#
-sub getFamilyEquivalent
-{
-my ($chars) = @_;
-
-
-	return $chars if ( length($chars) == 1 );
-
-	$chars =~ s/(\w)(?=\w)/$1,/og;
-	my @Chars = split ( /,/, $chars );
-	my $return;
-	foreach (@Chars) {
-		$char = $_;
-		foreach	( keys %AmharicClassEquivalence ) {
-			$return .= $_ if ( $AmharicClassEquivalence{$char} eq $AmharicClassEquivalence{$_} );
-		}
-	}
-
-	$return;
-}
-
-
 sub getRe
 {
-$_ = ($#_) ? $_[1] : $_[0];
+$_ = $_[$reIndex];
 
 
-	s/\[=(\p{Ethiopic})=\]/($AmharicEquivalence{$1}) ? "[$AmharicEquivalence{$1}]" : $1/eog;
-	s/\[=#(\p{Ethiopic})#=\]/($AmharicClassEquivalence{$1}) ? "[$AmharicClassEquivalence{$1}]" : $1/eog;
-	s/\[=#([\p{Ethiopic}]+)#=\]/Regexp::Ethiopic::setRange(getFamilyEquivalent($1),"all")/eog;
+	s/\[=(\p{InEthiopic})=\]/[$AmharicEquivalence{$1}]/g;
+	s/\[=#(\p{InEthiopic})#=\]/[$AmharicClassEquivalence{$1}]/g;
 
 	Regexp::Ethiopic::getRe ( $_ );
 }
@@ -208,11 +181,10 @@ $_ = ($#_) ? $_[1] : $_[0];
 
 __END__
 
-=encoding utf8
 
 =head1 NAME
 
-Regexp::Ethiopic::Amharic - Regular Expressions Support for Amharic Language.
+Regexp::Ethiopic::Amharic - Regular Expressions Support for Amharic Language
 
 =head1 SYNOPSIS
 
@@ -273,10 +245,10 @@ not yet been tested.
 
 =head1 BUGS
 
-None presently known.
+None known yet.
 
 =head1 AUTHOR
 
-Daniel Yacob,  L<dyacob@cpan.org|mailto:dyacob@cpan.org>
+Daniel Yacob,  L<Yacob@EthiopiaOnline.Net|mailto:Yacob@EthiopiaOnline.Net>
 
 =cut
